.. _profile_unselect:

**unselect** - Unselect a profile
=================================

Usage
---------

.. code::

    e4s-cl profile unselect

Description
------------

.. automodule:: e4s_cl.cli.commands.profile.unselect
